enum ExitPipelineMode {
Normal,
Force,
}Expand description
When we are exiting a pipeline, we can either force exiting or not. A normal exit
waits for Paint to update its state before exiting, and delegates layout exit to
script. A forced exit does not notify Paint, and exits layout without involving
script.
Variants