enum ScreenshotRequestState {
Pending,
WaitingOnScript,
}Expand description
When a ScreenshotReadinessRequest is received from the renderer, the Constellation
go through a variety of states to process them. This data structure represents those states.
Variants
Pending
The Constellation has received the ScreenshotReadinessRequest, but has not yet
forwarded it to the Pipeline’s of the requests’s WebView. This is likely because there
are still pending navigation changes in the Constellation. Once those changes are resolved
the request will be forwarded to the Pipelines.
WaitingOnScript
The Constellation has forwarded the ScreenshotReadinessRequest to the Pipelines of
the corresponding WebView. The Pipelines are waiting for a variety of things to happen in
order to report what appropriate display list epoch is for the screenshot. Once they all report
back, the Constellation considers that the request is handled, and the renderer is responsible
for waiting to take the screenshot.