struct BrowsingContextGroup {
top_level_browsing_context_set: FxHashSet<WebViewId>,
event_loops: HashMap<Host, Weak<EventLoop>>,
webgpus: HashMap<Host, WebGPU>,
}Expand description
A browsing context group.
https://html.spec.whatwg.org/multipage/#browsing-context-group
Fields
top_level_browsing_context_set: FxHashSet<WebViewId>A browsing context group holds a set of top-level browsing contexts.
event_loops: HashMap<Host, Weak<EventLoop>>The set of all event loops in this BrowsingContextGroup.
We store the event loops in a map
indexed by registered domain name (as a Host) to event loops.
It is important that scripts with the same eTLD+1,
who are part of the same browsing-context group
share an event loop, since they can use document.domain
to become same-origin, at which point they can share DOM objects.
webgpus: HashMap<Host, WebGPU>The set of all WebGPU channels in this BrowsingContextGroup.