enum TransferState {
Managed(MessagePortRouterId),
TransferInProgress(VecDeque<PortMessageTask>),
CompletionInProgress(MessagePortRouterId),
CompletionFailed(VecDeque<PortMessageTask>),
CompletionRequested(MessagePortRouterId, VecDeque<PortMessageTask>),
}Expand description
The state used by MessagePortInfo to represent the various states the port can be in.
Variants
Managed(MessagePortRouterId)
The port is currently managed by a given global, identified by its router id.
TransferInProgress(VecDeque<PortMessageTask>)
The port is currently in-transfer, and incoming tasks should be buffered until it becomes managed again.
CompletionInProgress(MessagePortRouterId)
A global has requested the transfer to be completed, it’s pending a confirmation of either failure or success to complete the transfer.
CompletionFailed(VecDeque<PortMessageTask>)
While a completion of a transfer was in progress, the port was shipped, hence the transfer failed to complete. We start buffering incoming messages, while awaiting the return of the previous buffer from the global that failed to complete the transfer.
CompletionRequested(MessagePortRouterId, VecDeque<PortMessageTask>)
While a completion failed, another global requested to complete the transfer. We are still buffering messages, and awaiting the return of the buffer from the global who failed.